==> nextcloud-20.0.10.tgz: nextcloud/apps/comments/l10n/cs.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáře",
    "You commented" : "Okomentovali jste",
    "%1$s commented" : "%1$s okomentován",
    "{author} commented" : "{author} okomentoval(a)",
    "You commented on %1$s" : "Okomentovali jste %1$s",
    "You commented on {file}" : "Okomentovali jste {file}",
    "%1$s commented on %2$s" : "%1$s okomentoval(a) %2$s",
    "{author} commented on {file}" : "{author} okomentoval(a) {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáře</strong> k souborům",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Byli jste zmíněni v souboru „{file}“, v komentáři od uživatele, který byl později smazán",
    "{user} mentioned you in a comment on “{file}”" : "{user} vás zmínil(a) v komentáři u „{file}“",
    "Files app plugin to add comments to files" : "Zásuvný modul do aplikace Soubory pro přidávání komentářů k souborům",
    "Edit comment" : "Upravit komentář",
    "Delete comment" : "Smazat komentář",
    "Cancel edit" : "Zrušit úpravu",
    "Post comment" : "Odeslat komentář",
    "No comments yet, start the conversation!" : "Zatím bez komentářů, začněte konverzaci!",
    "No more messages" : "Žádné další zprávy",
    "Retry" : "Zkusit znovu",
    "Unable to load the comments list" : "Nedaří se načíst seznam komentářů",
    "_%n unread comment_::_%n unread comments_" : ["%n nepřečtený komentář","%n nepřečtené komentáře","%n nepřečtených komentářů","%n nepřečtené komentáře"],
    "_1 new comment_::_{unread} new comments_" : ["Jeden nový komentář","{unread} nové komentáře","{unread} nových komentářů","{unread} nové komentáře"],
    "Comment" : "Komentář",
    "An error occurred while trying to edit the comment" : "Došlo k chybě při pokusu o úpravu komentáře",
    "Comment deleted" : "Komentář smazán",
    "An error occurred while trying to delete the comment" : "Došlo k chybě při pokusu o smazání komentáře",
    "An error occurred while trying to create the comment" : "Došlo k chybě při pokusu o vytvoření komentáře",
    "New comment …" : "Nový komentář…",
    "Post" : "Zveřejnit",
    "Cancel" : "Storno",
    "[Deleted user]" : "[Smazaný uživatel]",
    "More comments …" : "Více komentářů…",
    "Save" : "Uložit",
    "Allowed characters {count} of {max}" : "Využito {count} znaků z {max}",
    "Error occurred while retrieving comment with ID {id}" : "Došlo k chybě při načítání komentáře s identifikátorem {id}",
    "Error occurred while updating comment with id {id}" : "Došlo k chybě při aktualizování komentáře s id {id}",
    "Error occurred while posting comment" : "Došlo k chybě při zveřejňování komentáře"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/comments/l10n/cs.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáře",
    "You commented" : "Okomentovali jste",
    "%1$s commented" : "%1$s okomentován",
    "{author} commented" : "{author} okomentoval(a)",
    "You commented on %1$s" : "Okomentovali jste %1$s",
    "You commented on {file}" : "Okomentovali jste {file}",
    "%1$s commented on %2$s" : "%1$s okomentoval(a) %2$s",
    "{author} commented on {file}" : "{author} okomentoval(a) {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáře</strong> k souborům",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Byli jste zmíněni v souboru „{file}“, v komentáři od uživatele, který byl později smazán",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} vás zmínil(a) v komentáři u „{file}“",
    "Files app plugin to add comments to files" : "Zásuvný modul do aplikace Soubory pro přidávání komentářů k souborům",
    "Edit comment" : "Upravit komentář",
    "Delete comment" : "Smazat komentář",
    "Cancel edit" : "Zrušit úpravu",
    "Post comment" : "Odeslat komentář",
    "No comments yet, start the conversation!" : "Zatím bez komentářů, začněte konverzaci!",
    "No more messages" : "Žádné další zprávy",
    "Retry" : "Zkusit znovu",
    "Unable to load the comments list" : "Nedaří se načíst seznam komentářů",
    "_%n unread comment_::_%n unread comments_" : ["%n nepřečtený komentář","%n nepřečtené komentáře","%n nepřečtených komentářů","%n nepřečtené komentáře"],
    "_1 new comment_::_{unread} new comments_" : ["Jeden nový komentář","{unread} nové komentáře","{unread} nových komentářů","{unread} nové komentáře"],
    "Comment" : "Komentář",
    "An error occurred while trying to edit the comment" : "Došlo k chybě při pokusu o úpravu komentáře",
    "Comment deleted" : "Komentář smazán",
    "An error occurred while trying to delete the comment" : "Došlo k chybě při pokusu o smazání komentáře",
    "An error occurred while trying to create the comment" : "Došlo k chybě při pokusu o vytvoření komentáře",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Byli jste zmíněni v souboru „{file}“, v komentáři od uživatele, který byl později smazán",
    "{user} mentioned you in a comment on “{file}”" : "{user} vás zmínil(a) v komentáři u „{file}“",
    "New comment …" : "Nový komentář…",
    "Post" : "Zveřejnit",
    "Cancel" : "Storno",
    "[Deleted user]" : "[Smazaný uživatel]",
    "More comments …" : "Více komentářů…",
    "Save" : "Uložit",
    "Allowed characters {count} of {max}" : "Využito {count} znaků z {max}",
    "Error occurred while retrieving comment with ID {id}" : "Došlo k chybě při načítání komentáře s identifikátorem {id}",
    "Error occurred while updating comment with id {id}" : "Došlo k chybě při aktualizování komentáře s id {id}",
    "Error occurred while posting comment" : "Došlo k chybě při zveřejňování komentáře"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
